#include <iostream>
#include <fstream>
#include <vector>
#include <string>
#include <sstream>
#include <cassert>
#include <algorithm>
#include <iomanip>

using namespace std;

bool equivalent (vector<pair<int, int>> p, vector<pair<int, int>> q) {
  if (p.size() != q.size()) {
    return false;
  }
  sort(p.begin(), p.end());
  sort(q.begin(), q.end());
  for (int i = 0; i < (int) p.size(); i++) {
    if (p[i] != q[i]) {
      return false;
    }
  }
  return true;
}

bool is_numeric (string s) {
  if (s.size() > 6) {
    return false;
  }

  if (s.empty()) {
    return false;
  }

  for (char c : s) {
    if (c < '0' || c > '9') {
      return false;
    }
  }
  return true;
}

pair<bool, pair<string, string>> parse_line (string line) {
  vector<string> tokens;
  istringstream ss (line);
  string token;
  while (ss >> token) {
    tokens.push_back(token);
  }
  if ((int) tokens.size() != 2) {
    return make_pair(false, make_pair(string(), string()));
  }
  return make_pair(true, make_pair(tokens[0], tokens[1]));
}

const int NQ = 100000;
const int HYP_MIN = 20000000;

int main (int argc, char **argv) {
  ifstream input_file (argv[1]);
  /* ifstream answer_file (argv[2]); */
  ifstream student_file (argv[3]);

  int N, Q;
  input_file >> N >> Q;
  assert(N == 100000);
  assert(Q == 100000);

  vector<pair<int, int>> orig_ord;
  for (int i = 0; i < Q; i++) {
    int u, v;
    input_file >> u >> v;

    orig_ord.push_back(make_pair(u, v));
  }
  input_file.close();

  vector<string> student_output;
  while (student_file) {
    string str;
    getline(student_file, str);
    student_output.push_back(str);
  }
  student_file.close();

  if (!student_output.empty() && student_output.back().empty()) {
    student_output.pop_back();
  }

  if ((int) student_output.size() != Q) {
    cerr << "Presentation error: invalid number of lines!" << endl;
    cout << "0.0" << endl;
    return 0;
  }

  vector<pair<int, int>> student_ord;
  for (int i = 0; i < (int) student_output.size(); i++) {
    pair<bool, pair<string, string>> pr = parse_line(student_output[i]);
    if (!pr.first) {
      cerr << "Presentation error: invalid number of tokens on line " << i + 1 << "!" << endl;
      cout << "0.0" << endl;
      return 0;
    }

    if (!is_numeric(pr.second.first) || !is_numeric(pr.second.second)) {
      cerr << "Presentation error: non-numeric (or too long) token on line " << i + 1 << "!" << endl;
      cout << "0.0" << endl;
      return 0;
    }

    student_ord.push_back(make_pair(atoi(pr.second.first.c_str()), atoi(pr.second.second.c_str())));
  }

  if (!equivalent(orig_ord, student_ord)) {
    cerr << "Wrong answer: the output is not a permutation of the input!" << endl;
    cout << "0.0" << endl;
    return 0;
  }

  long long score = 0;
  pair<int, int> last = make_pair(1, 1);
  for (pair<int, int> cur : student_ord) {
    score += abs(cur.first - last.first);
    score += abs(cur.second - last.second);
    last = cur;
  }
  cerr << "OK" << endl;
  cout << fixed << setprecision(3) << min(1.0, (double) HYP_MIN / score) << endl;
}
