#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

inline int64_t hilbertOrder(int x, int y, int pow, int rotate) {
	if (pow == 0) {
		return 0;
	}
	int hpow = 1 << (pow-1);
	int seg = (x < hpow) ? (
		(y < hpow) ? 0 : 3
	) : (
		(y < hpow) ? 1 : 2
	);
	seg = (seg + rotate) & 3;
	const int rotateDelta[4] = {3, 0, 0, 1};
	int nx = x & (x ^ hpow), ny = y & (y ^ hpow);
	int nrot = (rotate + rotateDelta[seg]) & 3;
	int64_t subSquareSize = int64_t(1) << (2*pow - 2);
	int64_t ans = seg * subSquareSize;
	int64_t add = hilbertOrder(nx, ny, pow-1, nrot);
	ans += (seg == 1 || seg == 2) ? add : (subSquareSize - add - 1);
	return ans;
}

int64_t ord (pair<int, int> p) {
  return hilbertOrder(p.first, p.second, 17, 0);
}

bool comp (pair<int, int> p, pair<int, int> q) {
  return ord(p) < ord(q);
}

const int Q = 100000;

int main () {
  int n, q;
  cin >> n >> q;
  
  vector<pair<int, int>> queries (Q);
  for (int i = 0; i < Q; i++) {
    cin >> queries[i].first >> queries[i].second;
  }

  sort(queries.begin(), queries.end(), comp);

  for (int i = 0; i < Q; i++) {
    cout << queries[i].first << " " << queries[i].second << '\n';
  }
}
